@@ -705,6 +705,60 @@ class ConvAIModel:
             out_text = tokenizer.decode(out_ids, skip_special_tokens=True)
             print(out_text)
 
+    def interact_single(self, message, history, personality=None, encode_history=True):
+        """
+        Get Response from the model based on the history and message
+
+        Args:
+            message: A message to be sent to the model.
+            history: A list of sentences that repersents the interaction history between the model and the user.
+            personality (optional): A list of sentences that the model will use to build a personality.
+            encode_history (optional): If True, the history should be in text (string) form.
+                            The history will be tokenized and encoded.
+
+        Returns:
+            out_text: the response generated by the model based on the personality, history and message.
+            history: The updated history of the conversation. If encode_history is True, this will be in text form.
+                        If not, it will be in encoded form.
+        """
+        model = self.model
+        args = self.args
+        tokenizer = self.tokenizer
+        process_count = self.args.process_count
+
+        self._move_model_to_device()
+
+        if not personality:
+            dataset = get_dataset(
+                tokenizer,
+                None,
+                args.cache_dir,
+                process_count=process_count,
+                proxies=self.__dict__.get("proxies", None),
+                interact=True,
+            )
+            personalities = [dialog["personality"] for dataset in dataset.values() for dialog in dataset]
+            personality = random.choice(personalities)
+        else:
+            personality = [tokenizer.encode(s.lower()) for s in personality]
+
+        if encode_history:
+            raw_history = history.copy()
+            raw_history.append(message)
+            history = [tokenizer.encode(sentence) for sentence in history]
+        history.append(tokenizer.encode(message))
+        with torch.no_grad():
+            out_ids = self.sample_sequence(personality, history, tokenizer, model, args)
+        out_text = tokenizer.decode(out_ids, skip_special_tokens=True)
+
+        if encode_history:
+            raw_history.append(out_text)
+            history = raw_history
+        else:
+            history.append(out_ids)
+
+        return out_text, history
+
     def _threshold(self, x, threshold):
         if x >= threshold:
             return 1
